<?php
/**
 * Functions: E-mail
 *
 * @package        WordPress
 * @subpackage    WebTouch
 * @since        WebTouch 2018
 */

add_filter('wp_mail_content_type', function ($content_type) {
    return 'text/html';
});

// AJAX CALLS
add_action("wp_ajax_send_newsletter", "send_newsletter");
add_action("wp_ajax_nopriv_send_newsletter", "send_newsletter");

add_action("wp_ajax_send_lead", "send_lead");
add_action("wp_ajax_nopriv_send_lead", "send_lead");

add_action("wp_ajax_send_contact", "send_contact");
add_action("wp_ajax_nopriv_send_contact", "send_contact");

// Newsletter
function send_newsletter()
{

    $header_name = htmlspecialchars_decode(get_bloginfo('name'));
    $header_email = get_fields('options')['contact_email_news'];

    // Fields
    $fields = array();

    foreach ($_POST as $key => $value) {
        $fields[$key] = $value;
    }

    // template config
    $template_config = array(
        "template_site" => $header_name,
        "template_logo" => get_template_directory_uri() . '/assets/images/logo-duda.png',
        "template_color" => "#FC766A",
        "template_title" => "Novo Assinante Registrado",
        "template_footer_copyright" => "© " . $header_name . "<br> Todos os direitos reservados.",
    );

    // Template config user
    $template_config_user = array(
        "template_title" => "Assinatura Realizada",
        "name" => $fields['name_news'],
        "message" => "Obrigado por se cadastrar em nossa Newsletter.",
    );

    $data = array_merge($template_config, $fields);
    $data_user = array_merge($template_config, $template_config_user);

    $to = $header_email;
    $to_user = $data['email_news'];
    $subject = "Novo Assinante - " . $data['name_news'];
    $subject_user = "Cadastro realizado com sucesso - " . $header_name;
    $content = Timber::compile('views/email/newsletter.twig', $data);
    $content_user = Timber::compile('views/email/user.twig', $data_user);

    $headers = 'From: ' . $header_name . ' <contato@dudabundchen.com.br>' . "\r\n";

    wp_mail($to, $subject, $content, $headers);
    #wp_mail($to_user, $subject_user, $content_user, $headers);

    register_subscriber($to_user, $data['name_news'], 'Newsletter');

}

// Contact Lead
function send_lead()
{

    $header_name = htmlspecialchars_decode(get_bloginfo('name'));
    $header_email = 'contato@dudabundchen.com.br';

    // Fields
    $fields = array();

    foreach ($_POST as $key => $value) {
        $fields[$key] = $value;
    }

    // template config
    $template_config = array(
        "template_site" => $header_name,
        "template_logo" => get_template_directory_uri() . '/assets/images/logo-duda.png',
        "template_color" => "#FC766A",
        "template_title" => "Novo Contato Enviado",
        "template_footer_copyright" => "© " . $header_name . "<br> Todos os direitos reservados.",
    );

    // Template config user
    $template_config_user = array(
        "template_title" => "Contato Recebido",
        "name" => $fields['name'],
        "message" => "Obrigado por entrar em contato. Retornaremos em breve.",
    );

    $data = array_merge($template_config, $fields);
    $data_user = array_merge($template_config, $template_config_user);

    $emails_to = $header_email;
    $to_user = $data['email'];
    $subject = "Novo Contato - " . $data['name'];
    $subject_user = "Recebemos seu contato - " . $header_name;
    $content = Timber::compile('views/email/lead.twig', $data);
    $content_user = Timber::compile('views/email/user.twig', $data_user);

    $headers[] = 'From: ' . $header_name . ' <contato@hugs.com.br>' . "\r\n";

    wp_mail($emails_to, $subject, $content, $headers);
    wp_mail($to_user, $subject_user, $content_user, $headers);

    register_subscriber($to_user, $data['name'], $data['origin']);

}

function send_contact()
{

    $header_name = htmlspecialchars_decode(get_bloginfo('name'));
    $header_email = get_fields('options')['contact_subject'];

    // Fields
    $fields = array();

    foreach ($_POST as $key => $value) {
        $fields[$key] = $value;
    }

    // template config
    $template_config = array(
        "template_site" => $header_name,
        "template_logo" => get_template_directory_uri() . '/assets/images/logo-color.png',
        "template_color" => "#FC766A",
        "template_title" => "Novo Contato Enviado",
        "template_footer_copyright" => "© " . $header_name . "<br> Todos os direitos reservados.",
    );

    // Template config user
    $template_config_user = array(
        "template_title" => "Contato Recebido",
        "name" => $fields['name'],
        "message" => "Obrigado por entrar em contato. Retornaremos em breve.",
    );

    // Subject config
    $subjectIndex = $_POST["subject"];
    $subject_name = $header_email[$subjectIndex]["subject"];
    $emails_to = explode(',', $header_email[$subjectIndex]["email_subject"]);

    $fields['subject'] = $subject_name;

    $data = array_merge($template_config, $fields);
    $data_user = array_merge($template_config, $template_config_user);

    $to_user = $data['email'];
    $subject = "Novo Contato - " . $data['name'];
    $subject_user = "Recebemos seu contato - " . $header_name;
    $content = Timber::compile('views/email/contact.twig', $data);
    $content_user = Timber::compile('views/email/user.twig', $data_user);

    $headers[] = 'From: ' . $header_name . ' <contato@dudabundchen.com.br>' . "\r\n";

    foreach ($emails_to as $email) {
        $headers[] = 'Cc: <' . $email . '>' . "\r\n";
    }

    wp_mail($emails_to, $subject, $content, $headers);
    wp_mail($to_user, $subject_user, $content_user, $headers);

    if (isset($data['news'])) {
        register_subscriber($to_user, $data['name'], 'Contato');
    }

}

// Register email
function register_subscriber($email, $name, $origin)
{

    global $wpdb;

    date_default_timezone_set('America/Sao_Paulo');
    $date = date('Y-m-d H:i:s');

    $subscriberResult = $wpdb->query("SELECT * FROM $wpdb->posts WHERE post_title = '$email'");

    if ($subscriberResult == 0) {
        $wpdb->query($wpdb->prepare("INSERT INTO $wpdb->posts(post_title, post_type, post_date) VALUES (%s, %s, %s)", array($email, 'wt_subscriber', $date)));

        $id = $wpdb->insert_id;

        $wpdb->query($wpdb->prepare("INSERT INTO $wpdb->postmeta(post_id, meta_key, meta_value) VALUES (%s, %s, %s)", array($id, 'subscriber_name', $name)));
        $wpdb->query($wpdb->prepare("INSERT INTO $wpdb->postmeta(post_id, meta_key, meta_value) VALUES (%s, %s, %s)", array($id, 'subscriber_origin', $origin)));
    }

}

// Change from wp-email
add_filter('wp_mail_from', 'wt_mail_from');
function wt_mail_from($content_type)
{
    return "contato@dudabundchen.com.br";
}

add_filter('wp_mail_from_name', 'wt_mail_from_name');
function wt_mail_from_name($name)
{
    return htmlspecialchars_decode(get_bloginfo('name'));
}
