<?php

// Prevent styles on login page
function login_styles_reset($style)
{
    if (strpos($style, 'wp-admin-css') !== false) {
        $style = null;
    } elseif (strpos($style, 'colors-fresh-css') !== false) {
        $style = null;
    }
    return $style;
}
function custom_login_styles()
{
    add_filter('style_loader_tag', 'login_styles_reset');
}
add_action('login_init', 'custom_login_styles');

/**
 * Configuração dos assets e plugins do tema
 */

/* Register style fancybox css */
wp_register_style('fancybox', '//cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.2/jquery.fancybox.min.css');

/* Register script jQuery */
wp_register_script('jQuery', '//cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js', null, null, true);

/* Register script FancyBox js */
wp_register_script('fancybox', '//cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.2/jquery.fancybox.min.js', null, null, true);

/* Register script AOS js */
wp_register_script('aos', '//cdnjs.cloudflare.com/ajax/libs/aos/2.3.4/aos.js', null, null, true);

function add_static_assets()
{
    if (!is_admin()) {

        /* Vendor styles */
        wp_enqueue_style('fancybox');

        /** Theme styles */
        wp_enqueue_style('main', get_template_directory_uri() . '/dist/styles/main.css');

        /* Vendor scripts */
        wp_enqueue_script('jQuery');
        // wp_enqueue_script('aos');
        // wp_enqueue_script('fancybox');

        /* Theme scripts */
        wp_enqueue_script('main', get_template_directory_uri() . '/dist/scripts/main.js', null, null, true);
    }
}

add_action('wp_enqueue_scripts', 'add_static_assets', 0);


// Register Theme Features
function wt_theme_setup()
{

    // Add theme support via timber.php

    // Add theme support for Translation
    load_theme_textdomain('webtouch', get_template_directory() . '/languages');
}
add_action('after_setup_theme', 'wt_theme_setup');

// Remove WP Image Crop Sizes
function wt_theme_filter_image_sizes($sizes)
{
    // unset($sizes['thumbnail']);
    // unset($sizes['medium']);
    unset($sizes['medium_large']);
    unset($sizes['large']);

    return $sizes;
}
add_filter('intermediate_image_sizes_advanced', 'wt_theme_filter_image_sizes');

//Count
function getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0";
    }
    return $count;
}

function setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

//Rewrite Rule For Slugs
function wt_rewrite_rules()
{
    global $wp_rewrite;
    $wp_rewrite->author_base = 'autor';
    $wp_rewrite->search_base = 'busca';
    $wp_rewrite->comments_base = 'comentarios';
    $wp_rewrite->pagination_base = 'pagina';
    $wp_rewrite->flush_rules();
}
add_action('init', 'wt_rewrite_rules');

// Gallery Mansory
/*function wt_mansory($key)
{
    switch ($key % 5) {
        case 0:
            return "medium";
            break;
        case 1:
            return "mini";
            break;
        case 2:
            return "x-large";
            break;
        case 3:
            return "large";
            break;
        case 4:
            return "medium";
            break;
    }
}
add_action('init', 'wt_mansory');*/

//Rewrite Rule For Pagination Languages
$lang = get_bloginfo("language");
if ($lang == 'en-US') {
    add_action('init', 'pagination_english');
    function pagination_english()
    {
        $pagination_slug = 'page'; // change slug name
        $GLOBALS['wp_rewrite']->pagination_base = $pagination_slug;
        $GLOBALS['wp_rewrite']->flush_rules();
    }
}

// Search query
// Add Filter for Search
function SearchFilter($query) {
	if ($query->is_search) {

		$post_type = $_GET['tipo'];

		switch ($post_type) {
			case 'solucoes':
				$query->set('post_type', array('solutions'));
				break;
			case 'blog':
				$query->set('post_type', array('post'));
				break;
		}
	}
	return $query;
}

add_filter('pre_get_posts','SearchFilter');

// ACF Google maps API Key
function google_maps_key_init()
{
    acf_update_setting('google_api_key', '');
}

add_action('acf/init', 'google_maps_key_init');

// Options Page
if (function_exists('acf_add_options_page')) {

    acf_add_options_page(array(
        'page_title' => 'Opções Gerais',
        'menu_title' => 'Opções Gerais',
        'menu_slug' => 'site-general-options',
        'capability' => 'edit_posts',
        'redirect' => false,
    ));
}
